@@ -2,6 +2,7 @@ import nose.tools as nt
 
 import mock
 from mock import patch
+from nose.tools import assert_equal
 
 import morph_tool.loader as tested
 
@@ -42,3 +43,11 @@ def test_loader(f_mock):
         mock.call('/dir/test.abc', 42),
         mock.call('/dir/test.abc'),
     ])
+
+@patch('morphio.Morphology')
+def test_loader_no_cache(f_mock):
+    f_mock.configure_mock(side_effect=lambda *args: object())
+    loader = tested.MorphLoader('/dir', file_ext='abc', cache_size=0)
+    loader.get('test')
+    loader.get('test')
+    assert_equal(f_mock.call_count, 2)
